@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.013-3-ge99314f
+package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.014-8-g10b6654
 # ABSTRACT: Add contributor names from git to your distribution
 # KEYWORDS: plugin distribution metadata git contributors authors commits
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.014';
+our $VERSION = '0.015';
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
@@ -15,6 +15,7 @@ use Git::Wrapper 0.035;
 use Try::Tiny;
 use Path::Tiny 0.048;
 use Moose::Util::TypeConstraints 'enum';
+use List::UtilsBy 0.04 'uniq_by';
 use Unicode::Collate 0.53;
 use namespace::autoclean;
 
@@ -68,6 +69,7 @@ around dump_config => sub
                      ($dist_root->subsumes($p) ? $p->relative($dist_root) : $p)->stringify
                    } $self->paths ],
         $self->remove ? ( remove => '...' ) : (),
+        blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
 
     return $config;
@@ -111,11 +113,14 @@ sub _contributors
         );
     };
 
-    my @contributors = map { utf8::decode($_); m/^\s*\d+\s*(.*)$/g; } @data;
+    my @contributors = map { m/^\s*\d+\s*(.*)$/g; } @data;
 
     $self->log_debug([ 'extracted contributors from git: %s',
         sub { require Data::Dumper; Data::Dumper->new([ \@contributors ])->Indent(2)->Terse(1)->Dump } ]);
 
+    # remove duplicates by email address, keeping the latest associated name
+    @contributors = uniq_by { (/(<[^>]+>)/g)[-1] } @contributors;
+
     @contributors = Unicode::Collate->new(level => 1)->sort(@contributors) if $self->order_by eq 'name';
 
     if (not $self->include_authors)
@@ -156,8 +161,6 @@ sub _releaser
         $self->log('could not extract user.name and user.email configs from git');
         return;
     }
-    utf8::decode($username);
-    utf8::decode($email);
     $username . ' <' . $email . '>';
 }
 
@@ -186,6 +189,9 @@ sub _git
     my @result = $git->$command(@args);
     my $err = $git->ERR;
     $self->log(@$err) if @$err;
+    # TODO Git::Wrapper should really be decoding this for us, via a new
+    # (defaulting-to-false) utf8 flag
+    utf8::decode($_) foreach @result;
     return @result;
 }
 
@@ -203,7 +209,7 @@ Dist::Zilla::Plugin::Git::Contributors - Add contributor names from git to your
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -272,6 +278,9 @@ adding a F<.mailmap> file to your git repository, with entries formatted as
 described in "MAPPING AUTHORS" in C<git help shortlog>
 (L<https://www.kernel.org/pub/software/scm/git/docs/git-shortlog.html>).
 
+Duplicate names that share the same email address will be removed
+automatically (keeping the form associated with the latest commit).
+
 =head1 ADDING CONTRIBUTORS TO POD DOCUMENTATION
 
 You can add the contributor names to your module documentation by using
@@ -286,14 +295,6 @@ However, on Windows you might need to do a bit more: see
 L<https://github.com/msysgit/msysgit/wiki/Git-for-Windows-Unicode-Support> for
 supported versions and extra configurations you may need to apply.
 
-=head1 SUPPORT
-
-=for stopwords irc
-
-Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Git-Contributors>
-(or L<bug-Dist-Zilla-Plugin-Git-Contributors@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Git-Contributors@rt.cpan.org>).
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 SEE ALSO
 
 =over 4
@@ -330,17 +331,40 @@ L<Module::Install::Contributors>
 
 =for Pod::Coverage mvp_multivalue_args mvp_aliases metadata
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Git-Contributors>
+(or L<bug-Dist-Zilla-Plugin-Git-Contributors@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Git-Contributors@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+irc://irc.perl.org/#distzilla.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Karen Etheridge <ether@cpan.org>
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords Kent Fredric
+=for stopwords Kent Fredric Mohammad S Anwar
+
+=over 4
+
+=item *
 
 Kent Fredric <kentnl@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
+=item *
+
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2014 by Karen Etheridge.
 
